﻿Public Class CSVDownload
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        ' ログイン情報の取得
        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がないときはエラー
        If accountInfo Is Nothing Then
            Response.Redirect("Maintenance.aspx")
        End If

        ' 権限がないときはエラー
        If Not accountInfo.roleCSVDownload Then
            Response.Redirect("Maintenance.aspx")
        End If

        If Not IsPostBack Then
            ' エラーメッセージの設定
            Me.reqValFromDate.ErrorMessage = "開始日付を入力してください"
            Me.reqValToDate.ErrorMessage = "終了日付を入力してください"
        End If
    End Sub

    Protected Sub download_Click(sender As Object, e As EventArgs) Handles download.Click
        ' バリデーションの実行
        Page.Validate()

        ' バリデーションエラーが発生したときは処理を続けない
        If Not Page.IsValid Then
            Return
        End If

        ' コネクションストリングの取得
        Dim connStr As String = Util.GetConnectionString
        ' データコンテキストの設定
        Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)
        ' モデルの設定
        Dim model As DBModelRequestData = New DBModelRequestData

        ' 日付の設定
        Dim fromDate As DateTime = DateTime.Parse(Me.fromDate.Text)
        Dim toDate As DateTime = DateTime.Parse(Me.toDate.Text).AddDays(1)

        Try
            ' データの取得
            model.RequestData = From t In dc.GetTable(Of RequestData)() Select t
                      Where t.REQUEST_DATE >= fromDate AndAlso t.REQUEST_DATE <= toDate
        Catch ex As Exception
            Response.Redirect("Maintenance.aspx")
        End Try

        ' カウントの取得
        Dim count As Integer = model.RequestData.Count

        'コンテントタイプ 
        Response.ContentType = "application/octet-stream"

        '添付ファイル 
        Response.AddHeader("Content-Disposition", "attachment; filename=" + HttpUtility.UrlEncode("CSV_" & Me.fromDate.Text.Replace("/", "") & "_" & Me.toDate.Text.Replace("/", "") & ".csv"))


        Dim csvstr As StringBuilder = New StringBuilder
        If model.RequestData.Count = 0 Then
            csvstr.Append("No Data")
        Else
            For Each item In model.RequestData
                csvstr.Append(item.SEQ_ID & ",")
                csvstr.Append(item.SEI_KANJI & ",")
                csvstr.Append(item.MEI_KANJI & ",")
                csvstr.Append(item.SEI_KANA & ",")
                csvstr.Append(item.MEI_KANA & ",")
                csvstr.Append(item.BIRTH_DATE & ",")
                csvstr.Append(item.GENDER_TEXT & ",")
                csvstr.Append(item.ZIP1 & "-" & item.ZIP2 & ",")
                csvstr.Append(item.ADDRESS1 & ",")
                csvstr.Append(item.ADDRESS2 & ",")
                csvstr.Append(item.ADDRESS3 & ",")
                csvstr.Append(item.ADDRESS4 & ",")
                If item.TEL1 <> "" Then
                    csvstr.Append(item.TEL1 & "-" & item.TEL2 & "-" & item.TEL3 & ",")
                Else
                    csvstr.Append(",")
                End If
                If item.M_TEL1 <> "" Then
                    csvstr.Append(item.M_TEL1 & "-" & item.M_TEL2 & "-" & item.M_TEL3 & ",")
                Else
                    csvstr.Append(",")
                End If

                csvstr.Append(item.E_MAIL & ",")
                csvstr.Append(item.OCCUPATION_TEXT & ",")
                csvstr.Append(item.REQUEST_DATE.ToString("yyyy/MM/dd HH:mm:ss") & vbCrLf)
            Next
        End If

        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)
        'ログの出力
        Try
            dc.insertDownloadLog(accountInfo.operatorId, HttpUtility.UrlEncode("CSV_" & Me.fromDate.Text.Replace("/", "") & "_" & Me.toDate.Text.Replace("/", "") & ".csv"), count, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)
        Catch ex As Exception
            Response.Redirect("Maintenance.aspx")
        End Try

        'CSV出力 
        Response.Write(csvstr.ToString)

        'レスポンス出力終了 
        Response.End()



    End Sub

    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles _
        cusValFromDate.ServerValidate, _
        cusValToDate.ServerValidate

        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        Select Case cusVal.ID
            Case cusValFromDate.ID
                If Me.fromDate.Text <> "" Then
                    If Not IsDate(Me.fromDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付の形式が不正です"
                    ElseIf Me.fromDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付は10文字以内で入力してください"
                    End If
                End If
            Case cusValToDate.ID
                If Me.toDate.Text <> "" Then
                    If Not IsDate(Me.toDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付の形式が不正です"
                    ElseIf Me.toDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付は10文字以内で入力してください"
                    End If

                End If
               
        End Select


    End Sub
End Class