﻿Public Class DownloadLog
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        '　ログイン情報の取得
        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がないときはエラー
        If accountInfo Is Nothing Then
            Response.Redirect("Maintenance.aspx")
        End If

        ' 権限がないときはエラー
        If Not accountInfo.roleUserManager Then
            Response.Redirect("Maintenance.aspx")
        End If

    End Sub

    Protected Sub search_Click(sender As Object, e As EventArgs) Handles search.Click
        ' バリデーションの実行
        Page.Validate()

        ' バリデーションエラーが発生した時は抜ける
        If Not Page.IsValid Then
            Return
        End If

        ' データの取得
        GridViewBind(0)
    End Sub

    Private Sub GridViewBind(ByVal page As Integer)
        ' コネクションストリングの取得
        Dim connStr As String = Util.GetConnectionString
        ' データコンテキストの取得
        Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)

        ' モデルの生成
        Dim model As DBModelDownloadLog = New DBModelDownloadLog


        Dim fromDate As DateTime = DateTime.MinValue
        If Me.fromDate.Text <> "" Then
            fromDate = DateTime.Parse(Me.fromDate.Text)
        End If
        Dim toDate As DateTime = DateTime.MaxValue
        If Me.toDate.Text <> "" Then
            toDate = DateTime.Parse(Me.toDate.Text).AddDays(1)
        End If

        ' ダウンロードログデータの取得
        model.DownloadLog = (From t In dc.GetTable(Of DownloadLog)() Select t
                             Order By t.DOWNLOAD_DATE Descending
                             Where (Me.operatorId.Text = "" OrElse t.OPERATOR_ID.Contains(Me.operatorId.Text)) AndAlso
                                 (Me.fromDate.Text = "" OrElse t.DOWNLOAD_DATE >= fromDate) AndAlso
                                  (Me.toDate.Text = "" OrElse t.DOWNLOAD_DATE <= toDate)).Take(Me.viewCount.SelectedValue)
        Me.downloadLogList.PageIndex = page
        Me.downloadLogList.PageSize = Util.GetAppSetting("PageSizeDownloadLogList")
        Me.downloadLogList.DataSource = model.DownloadLog
        Me.downloadLogList.DataBind()
    End Sub

    ' カスタムバリデーション
    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles _
     cusValOperatorId.ServerValidate, _
     cusValFromDate.ServerValidate, _
     cusValToDate.ServerValidate

        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        Select Case cusVal.ID
            Case cusValOperatorId.ID
                If Me.operatorId.Text <> "" Then
                    If Me.operatorId.Text.Length > 20 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "オペレータIDは20文字以内で入力してください"
                    End If
                End If
            Case cusValFromDate.ID
                If Me.fromDate.Text <> "" Then
                    If Not IsDate(Me.fromDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付の形式が不正です"
                    ElseIf Me.fromDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付は10文字以内で入力してください"
                    End If
                End If
            Case cusValToDate.ID
                If Me.toDate.Text <> "" Then
                    If Not IsDate(Me.toDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付の形式が不正です"
                    ElseIf Me.toDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付は10文字以内で入力してください"
                    End If
                End If
        End Select


    End Sub

    Private Sub downloadLogList_PageIndexChanging(sender As Object, e As System.Web.UI.WebControls.GridViewPageEventArgs) Handles downloadLogList.PageIndexChanging
        GridViewBind(e.NewPageIndex)
    End Sub
End Class