﻿Public Class EditUser
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        ' ログイン情報の取得
        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がないときはエラー
        If accountInfo Is Nothing Then
            Response.Redirect("Maintenance.aspx")
        End If

        ' 権限がないときはエラー
        If Not accountInfo.roleUserManager Then
            Response.Redirect("Maintenance.aspx")
        End If

        If Not Me.IsPostBack Then
            ' エラーメッセージの設定
            Me.reqValOperatorName.ErrorMessage = "オペレータ名を入力してください"

            ' IDの取得
            Dim id As String

            id = Request.QueryString("id")
            If id Is Nothing Then
                id = Session("EditUserOperatorId")
            Else
                Session("EditUserOperatorId") = id

                Session("EditUserOperatorName") = Nothing
                Session("EditUserRole") = Nothing
                Session("EditUserLock") = Nothing
                Session("EditUserDisabled") = Nothing
            End If

            ' IDがないときはエラー
            If id Is Nothing Then
                Response.Redirect("Maintenance.aspx")
            End If

            ' チェックリストボックスに設定
            Util.AddListItem(Me.role, "4")

            ' コネクションストリングの取得
            Dim connStr As String = Util.GetConnectionString
            ' データコンテキストの生成
            Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)

            ' モデルの生成
            Dim model As DBModelUserMst = New DBModelUserMst

            ' ユーザ情報の取得
            model.UserMst = From t In dc.GetTable(Of MstUser)() Select t Where t.OPERATOR_ID = id

            ' ユーザ情報が見つからないときはエラー
            If model.UserMst.Count = 0 Then
                Response.Redirect("Maintenance.aspx")
            End If

            ' 表示データのセット
            Me.operatorId.Text = model.UserMst.First.OPERATOR_ID.ToString
            Me.operatorName.Text = model.UserMst.First.OPERATOR_NAME.ToString

            Dim role As String = model.UserMst.First.ROLE.ToString
            Dim array As String() = role.Split(",")
            For Each item As ListItem In Me.role.Items
                For i As Integer = 0 To array.Length - 1
                    If item.Value = array(i) Then
                        item.Selected = True
                    End If
                Next
            Next

            Me.lock.Checked = model.UserMst.First.LOCK
            Me.disabled.Checked = model.UserMst.First.DISABLED

            ' セッションの復元
            If Not Session("EditUserOperatorName") Is Nothing Then
                Me.operatorId.Text = Session("EditUserOperatorId")
                Me.operatorName.Text = Session("EditUserOperatorName")
                Dim role2 As String = Session("EditUserRole")
                Dim array2 As String() = role2.Split(",")
                For Each item As ListItem In Me.role.Items
                    For i As Integer = 0 To array2.Length - 1
                        If item.Value = array2(i) Then
                            item.Selected = True
                        End If
                    Next
                Next
                Me.lock.Checked = Session("EditUserLock")
                Me.disabled.Checked = Session("EditUserDisabled")
            End If

        End If

    End Sub

    Protected Sub back_Click(sender As Object, e As EventArgs) Handles back.Click
        Response.Redirect("UserManager.aspx")
    End Sub

    Protected Sub next_Click(sender As Object, e As EventArgs) Handles [next].Click
        ' バリデーションの実行
        Page.Validate()

        ' バリデーションエラーが発生した時は処理を続行しない
        If Not Page.IsValid Then
            Return
        End If

        ' セッションに格納
        Session("EditUserOperatorName") = Me.operatorName.Text
        Dim role As String = ""
        For Each item As ListItem In Me.role.Items
            If item.Selected Then
                role = role & item.Value & ","
            End If
        Next
        If role.EndsWith(",") Then
            role = role.Substring(0, role.Length - 1)
        End If
        Session("EditUserRole") = role

        Session("EditUserLock") = Me.lock.Checked
        Session("EditUserDisabled") = Me.disabled.Checked

        ' 確認画面へ遷移
        Response.Redirect("EditUserConfirm.aspx")
    End Sub


    ' カスタムバリデーション
    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles _
     cusValOperatorName.ServerValidate, _
     cusValRole.ServerValidate

        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        Select Case cusVal.ID
            Case cusValOperatorName.ID
                If Util.IncludeSpecialCharacter(Me.operatorName.Text) Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータ名に機種依存文字は使えません"
                ElseIf Me.operatorName.Text.Length > 20 Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータ名は20文字以内で入力してください"
                End If
            Case cusValRole.ID
                Dim flag As Boolean = False
                For Each item As ListItem In Me.role.Items
                    If item.Selected Then
                        flag = True
                        Exit For
                    End If
                Next

                If flag = False Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "ロールは1つは選択してください"
                End If
        End Select
    End Sub
End Class