﻿Public Class Login
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Not Me.IsPostBack Then
            ' エラーメッセージの設定
            Me.reqValOperatorId.ErrorMessage = "オペレータIDを入力してください"
            Me.reqValPassword.ErrorMessage = "パスワードを入力してください"
        End If
    End Sub

    Protected Sub login_Click(sender As Object, e As EventArgs) Handles login.Click
        ' バリデーション実行
        Page.Validate()

        ' バリデーションエラーが発生した時は処理しない
        If Not Page.IsValid Then
            Return
        End If

        ' コネクションストリングの取得
        Dim connStr As String = Util.GetConnectionString
        ' データコンテキストの生成
        Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)
        ' モデルの宣言
        Dim model As DBModelUserMst = New DBModelUserMst

        ' 指定したオペレータIDのデータ取得
        model.UserMst = From t In dc.GetTable(Of MstUser)() Where t.OPERATOR_ID = Me.operatorId.Text


        Try
            ' ログインストアドの実行
            dc.executeLogin(Me.operatorId.Text, True, 0, False, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)
        Catch ex As Exception
            Response.Redirect("Maintenance.aspx")
        End Try

        ' ログイン情報の生成
        Dim accountInfo As AccountInfo = New AccountInfo
        accountInfo.operatorId = model.UserMst.First.OPERATOR_ID
        accountInfo.operatorName = model.UserMst.First.OPERATOR_NAME

        Dim role As String = model.UserMst.First.ROLE
        Dim array As String() = role.Split(",")
        For i As Integer = 0 To array.Length - 1
            Select Case array(i)
                Case "1"
                    accountInfo.roleRead = True
                Case "2"
                    accountInfo.roleWrite = True
                Case "3"
                    accountInfo.roleCSVDownload = True
                Case "4"
                    accountInfo.roleUSerManager = True
            End Select
        Next

        ' ログイン情報をセッションに保存
        Session("AccountInfo") = accountInfo

        Response.Redirect("Default.aspx")

    End Sub


    ' カスタムバリデーションに実行
    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles cusValLogin.ServerValidate
        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        ' オペレータIDとパスワードが入力されたとき判定する
        If Me.operatorId.Text <> "" AndAlso Me.password.Text <> "" Then

            ' コネクションストリングの取得
            Dim connStr As String = Util.GetConnectionString
            ' データコンテキストの生成
            Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)
            ' モデルの宣言
            Dim model As DBModelUserMst = New DBModelUserMst
            ' 指定のオペレータIDのユーザデータを取得
            model.UserMst = From t In dc.GetTable(Of MstUser)() Where t.OPERATOR_ID = Me.operatorId.Text

            ' 入力パスワードをSHA256で暗号化
            Dim encryptPassword As String = Crypt.EncryptSHA256(Me.password.Text)

            If model.UserMst.Count = 0 Then ' ユーザデータが存在しないとき
                args.IsValid = False
                cusVal.ErrorMessage = "オペレータIDまたはパスワードが間違っています"

                Try
                    ' ログに記録
                    dc.insertLoginLog(Me.operatorId.Text, False, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)
                Catch ex As Exception
                    Response.Redirect("Maintenance.aspx")
                End Try


            ElseIf model.UserMst.First.LOCK = True Then ' ロックされているとき
                args.IsValid = False
                cusVal.ErrorMessage = "ご指定のオペレータIDがロックされています"
            ElseIf model.UserMst.First.DISABLED = True Then ' 無効化されているとき
                args.IsValid = False
                cusVal.ErrorMessage = "ご指定のオペレータIDが無効化されています"
            ElseIf model.UserMst.First.ENCRYPTED_PASSWORD <> encryptPassword Then   ' パスワードが間違っているとき
                args.IsValid = False
                cusVal.ErrorMessage = "オペレータIDまたはパスワードが間違っています"

                ' 現在の失敗カウントを取得
                Dim failedCount As Integer = model.UserMst.First.FAILED_COUNT
                ' 失敗カウントをインクリメント
                failedCount = failedCount + 1
                ' 失敗カウントが規定回数以上だったらロックフラグをセット
                Dim lock As Boolean = False
                If failedCount >= CInt(Util.GetAppSetting("PasswordFailedCount")) Then
                    lock = True
                End If
                Try
                    ' ログイン処理を実行
                    dc.executeLogin(Me.operatorId.Text, False, failedCount, lock, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)
                Catch ex As Exception
                    Response.Redirect("Maintenance.aspx")
                End Try

            ElseIf model.UserMst.First.INITIAL_PASSWORD = True Then 'パスワードが初期化された状態だったら
                args.IsValid = False
                cusVal.ErrorMessage = "パスワードが初期化されています。パスワードを更新してください"
            ElseIf CDate(model.UserMst.First.LAST_PASSWORD_CHANGE).AddDays(CInt(Util.GetAppSetting("PasswordExpirationDay"))) < DateTime.Now Then   ' パスワードの有効期限が過ぎていたら
                args.IsValid = False
                cusVal.ErrorMessage = "パスワードの有効期限が過ぎています。パスワードを更新してください"
            End If
        End If
    End Sub
End Class