﻿Public Class NewUser
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        ' ログイン情報の取得
        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がないときはエラー
        If accountInfo Is Nothing Then
            Response.Redirect("Maintenance.aspx")
        End If

        ' 権限がないときはエラー
        If Not accountInfo.roleUserManager Then
            Response.Redirect("Maintenance.aspx")
        End If

        If Not Me.IsPostBack Then
            ' エラーメッセージの設定
            Me.reqValOperatorId.ErrorMessage = "オペレータIDを入力してください"
            Me.reqValOperatorName.ErrorMessage = "オペレータ名を入力してください"
            Me.compValPassword.ErrorMessage = "パスワードおよびパスワード（確認）が異なります"

            ' ロールにデータを設定
            Util.AddListItem(Me.role, "4")

            ' セッション情報を復元
            Me.operatorId.Text = Session("NewUserOperatorId")
            Me.operatorName.Text = Session("NewUserOperatorName")
            If Not Session("NewUserRole") Is Nothing Then
                Dim array As String() = Session("NewUserRole").ToString.Split(",")

                For Each item As ListItem In Me.role.Items
                    For i As Integer = 0 To array.Length - 1
                        If item.Value = array(i) Then
                            item.Selected = True
                        End If
                    Next
                Next

            End If
        End If
    End Sub

    Protected Sub back_Click(sender As Object, e As EventArgs) Handles back.Click
        Response.Redirect("UserManager.aspx")
    End Sub

    Protected Sub next_Click(sender As Object, e As EventArgs) Handles [next].Click
        ' バリデーションの実行
        Page.Validate()

        ' バリデーションエラーが発生した時は処理を止める
        If Not Page.IsValid Then
            Return
        End If

        ' セッションに格納
        Session("NewUserOperatorId") = Me.operatorId.Text
        Session("NewUserOperatorName") = Me.operatorName.Text
        Dim role As String = ""
        For Each item As ListItem In Me.role.Items
            If item.Selected Then
                role = role & item.Value & ","
            End If
        Next
        If role.EndsWith(",") Then
            role = role.Substring(0, role.Length - 1)
        End If
        Session("NewUserRole") = role
        Session("NewUserPassword") = Me.password1.Text

        ' 確認画面へ遷移
        Response.Redirect("NewUserConfirm.aspx")
    End Sub

    ' カスタムバリデーション
    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles _
        cusValOperatorId.ServerValidate, _
        cusValOperatorName.ServerValidate, _
        cusValRole.ServerValidate, _
        cusValPassword1.ServerValidate

        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        Select Case cusVal.ID
            Case cusValOperatorId.ID
                If Not Util.IsAlphaNumeric(Me.operatorId.Text) Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータIDは半角英数字で入力してください"
                ElseIf Me.operatorId.Text.Length > 10 Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータIDは10文字以内で入力してください"
                Else
                    Dim connStr As String = Util.GetConnectionString
                    Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)
                    Dim model As DBModelUserMst = New DBModelUserMst
                    model.UserMst = From t In dc.GetTable(Of MstUser)() Where t.OPERATOR_ID = Me.operatorId.Text
                    If model.UserMst.Count > 0 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "オペレータIDはすでにに登録されています"
                    End If

                End If
            Case cusValOperatorName.ID
                If Util.IncludeSpecialCharacter(Me.operatorName.Text) Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータ名に機種依存文字は使えません"
                ElseIf Me.operatorName.Text.Length > 20 Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "オペレータ名は20文字以内で入力してください"
                End If
            Case cusValRole.ID
                Dim flag As Boolean = False
                For Each item As ListItem In Me.role.Items
                    If item.Selected Then
                        flag = True
                        Exit For
                    End If
                Next

                If flag = False Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "ロールは1つは選択してください"
                End If

            Case cusValPassword1.ID
                If Not Util.ValidatePassword(Me.password1.Text) Then
                    args.IsValid = False
                    cusVal.ErrorMessage = "パスワードは半角英数字6文字-20文字で入力してください。また、英大文字、英小文字、数字の3種類の文字を含む必要があります"
                End If
        End Select
    End Sub
End Class