﻿Public Class Status
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        ' ログイン情報の取得
        Dim accountInfo As AccountInfo = DirectCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がないときはエラー
        If accountInfo Is Nothing Then
            Response.Redirect("Maintenance.aspx")
        End If

        ' 権限がないときはエラー
        If Not (accountInfo.roleRead Or accountInfo.roleWrite) Then
            Response.Redirect("Maintenance.aspx")
        End If

    End Sub

    ' ページ番号が更新されたとき
    Private Sub dataList_PageIndexChanging(sender As Object, e As System.Web.UI.WebControls.GridViewPageEventArgs) Handles dataList.PageIndexChanging
        ' データグリッドの再表示
        GridViewBind(e.NewPageIndex)

    End Sub

    ' データグリッドの表示
    Private Sub GridViewBind(ByVal page As Integer)

        ' コネクションストリングの取得
        Dim connStr As String = Util.GetConnectionString
        ' データコンテキストの生成
        Dim dc As WebFormDBDataContext = New WebFormDBDataContext(connStr)
        ' モデルの宣言
        Dim model As DBModelRequestData = New DBModelRequestData


        Dim seqId As Integer = 0
        If Me.seqId.Text <> "" Then
            seqId = CInt(Me.seqId.Text)
        End If
        Dim fromDate As DateTime = DateTime.MinValue
        If Me.fromDate.Text <> "" Then
            fromDate = DateTime.Parse(Me.fromDate.Text)
        End If
        Dim toDate As DateTime = DateTime.MaxValue
        If Me.toDate.Text <> "" Then
            toDate = DateTime.Parse(Me.toDate.Text).AddDays(1)
        End If

        Dim seiKanji As String = ReplaceSingleQuote(Me.seiKanji.Text)
        Dim meiKanji As String = ReplaceSingleQuote(Me.meiKanji.Text)

        ' データの取得
        model.RequestData = (From t In dc.GetTable(Of RequestData)() Select t
                             Order By t.REQUEST_DATE Descending
                             Where (Me.seqId.Text = "" OrElse t.SEQ_ID = seqId) AndAlso
                                  (Me.seiKanji.Text = "" OrElse t.SEI_KANJI = seiKanji) AndAlso
                                   (Me.meiKanji.Text = "" OrElse t.MEI_KANJI = meiKanji) AndAlso
                                 (Me.seiKana.Text = "" OrElse t.SEI_KANA = Me.seiKana.Text) AndAlso
                                 (Me.meiKana.Text = "" OrElse t.MEI_KANA = Me.meiKana.Text) AndAlso
                                 (Me.zip.Text = "" OrElse (t.ZIP1 & t.ZIP2) = Me.zip.Text) AndAlso
                                 (Me.email.Text = "" OrElse t.E_MAIL = Me.email.Text) AndAlso
                                 (Me.fromDate.Text = "" OrElse t.REQUEST_DATE >= fromDate) AndAlso
                                  (Me.toDate.Text = "" OrElse t.REQUEST_DATE <= toDate)).Take(Me.viewCount.SelectedValue)
        Me.dataList.PageIndex = page
        Me.dataList.PageSize = Util.GetAppSetting("PageSizeRequestList")
        Me.dataList.DataSource = model.RequestData
        Me.dataList.DataBind()
    End Sub

    Protected Sub search_Click(sender As Object, e As EventArgs) Handles search.Click
        ' バリデーションの実行
        Page.Validate()
        ' バリデーションエラーが発生した時は何もしない
        If Not Page.IsValid Then
            Return
        End If
        ' トリム
        TrimSpace()
        ' グリッドの再表示
        GridViewBind(0)
    End Sub

    ' クリアボタンを押したとき
    Protected Sub clear_Click(sender As Object, e As EventArgs) Handles clear.Click
        Me.seqId.Text = ""
        Me.seiKanji.Text = ""
        Me.meiKanji.Text = ""
        Me.seiKana.Text = ""
        Me.meiKana.Text = ""
        Me.zip.Text = ""
        Me.email.Text = ""
        Me.fromDate.Text = ""
        Me.toDate.Text = ""
        Me.viewCount.SelectedValue = "100"

        Me.dataList.DataSource = Nothing
        Me.dataList.DataBind()
    End Sub

    ' トリム
    Private Sub TrimSpace()
        Me.seqId.Text = Me.seqId.Text.Trim
        Me.seiKanji.Text = Me.seiKanji.Text.Trim
        Me.meiKanji.Text = Me.meiKanji.Text.Trim
        Me.seiKana.Text = Me.seiKana.Text.Trim
        Me.meiKana.Text = Me.meiKana.Text.Trim
        Me.zip.Text = Me.zip.Text.Trim
        Me.email.Text = Me.email.Text.Trim
        Me.fromDate.Text = Me.fromDate.Text.Trim
        Me.toDate.Text = Me.toDate.Text.Trim

    End Sub

    Private Function ReplaceSingleQuote(ByVal str As String)
        Return str.Replace("'", "''")
    End Function

    ' カスタムバリデーションの実行
    Private Sub CustomValidate_ServerValidate(ByVal source As System.Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles _
        cusValSeqId.ServerValidate, _
        cusValSeiKanji.ServerValidate, _
        cusValMeiKanji.ServerValidate, _
        cusValSeiKana.ServerValidate, _
        cusValMeiKana.ServerValidate, _
        cusValZip.ServerValidate, _
        cusValEMail.ServerValidate, _
        cusValFromDate.ServerValidate, _
        cusValToDate.ServerValidate

        Dim cusVal As CustomValidator = DirectCast(source, UI.WebControls.CustomValidator)

        Select Case cusVal.ID
            Case cusValSeqId.ID
                If Me.seqId.Text <> "" Then
                    If Not Util.IsNumeric(Me.seqId.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "申込番号は数字で入力してください"
                    ElseIf Me.seqId.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "申込番号は10桁以内で入力してください"
                    End If
                End If

            Case cusValSeiKanji.ID
                If Me.seiKanji.Text <> "" Then
                    If Me.seiKanji.Text.Length > 20 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "姓（漢字）は20文字以内で入力してください"
                    End If

                End If
            Case cusValMeiKanji.ID
                If Me.meiKanji.Text <> "" Then
                    If Me.meiKanji.Text.Length > 20 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "名（漢字）は20文字以内で入力してください"
                    End If
                End If
            Case cusValSeiKana.ID
                If Me.seiKana.Text <> "" Then
                    If Not Util.IsKatakana(Me.seiKana.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "姓（カナ）はカタカナで入力してください"
                    ElseIf Me.seiKana.Text.Length > 20 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "姓（カナ）は20文字以内で入力してください"
                    End If
                End If
            Case cusValMeiKana.ID
                If Me.meiKana.Text <> "" Then
                    If Not Util.IsKatakana(Me.meiKana.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "名（カナ）はカタカナで入力してください"
                    ElseIf Me.meiKana.Text.Length > 20 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "名（カナ）は20文字以内で入力してください"
                    End If
                End If
            Case cusValZip.ID
                If Me.zip.Text <> "" Then
                    If Not Util.IsNumeric(Me.zip.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "郵便番号は数字で入力してください"
                    ElseIf Me.zip.Text.Length <> 7 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "郵便番号は7桁の数字で入力してください"
                    End If
                End If
            Case cusValEMail.ID
                If Me.email.Text <> "" Then
                    If Not Util.IsMail(Me.email.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "メールアドレスの形式が不正です"
                    ElseIf Me.email.Text.Length > 50 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "メールアドレスは50文字以内で入力してください"
                    End If
                End If
            Case cusValFromDate.ID
                If Me.fromDate.Text <> "" Then
                    If Not IsDate(Me.fromDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付の形式が不正です"
                    ElseIf Me.fromDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "開始日付は10文字以内で入力してください"
                    End If
                End If
            Case cusValToDate.ID
                If Me.toDate.Text <> "" Then
                    If Not IsDate(Me.toDate.Text) Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付の形式が不正です"
                    ElseIf Me.toDate.Text.Length > 10 Then
                        args.IsValid = False
                        cusVal.ErrorMessage = "終了日付は10文字以内で入力してください"
                    End If
                End If
        End Select


    End Sub
End Class